﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;

namespace GameAtlas.Models
{
    public class Manager : INotifyPropertyChanged
    {
        
        public List<Admin> Admins { get; private set; }
        public List<Utilisateur> Utilisateurs { get; private set; }

        private ObservableCollection<Jeu> listJeux;
        public ObservableCollection<Jeu> ListJeux
        { 
            get
            {
                return listJeux;
            }
            set
            {
                listJeux = value;
                OnPropertyChanged();
            }
        }

        public IPersistanceManager Persistance { get; set; }

        public Utilisateur ConnectedUser
        {
            get => connectedUser;
            set
            {
                connectedUser = value;
                OnPropertyChanged();
            }
        }
        private Utilisateur connectedUser;

        public event PropertyChangedEventHandler? PropertyChanged;

        public void OnPropertyChanged([CallerMemberName] string propertyName = null)
            => PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));

        public Manager(IPersistanceManager persistance)
        {
            Utilisateurs = new List<Utilisateur>();
            ListJeux = new ObservableCollection<Jeu>();
            Persistance = persistance;
            ConnectedUser = null;
        }

        public Manager() {
            ListJeux = new ObservableCollection<Jeu>();
            Admins = new List<Admin>();
            Utilisateurs = new List<Utilisateur>();
            ConnectedUser = null;
        }

        public void AddJeux(Jeu jeux)
        {
            ListJeux.Add(jeux);
        }

        public void AddAdmin(Admin admin)
        {
            Admins.Add(admin);
        }

        public void AddUtilisateur(Utilisateur utilisateur)
        {
            Utilisateurs.Add(utilisateur);
        }

        public void ChargerDonnees()
        {
            var donnees = Persistance.ChargeDonnees();

            foreach (var user in donnees.Item2)
            {
                AddUtilisateur(user);
            }

            foreach (var jeu in donnees.Item1)
            {
                AddJeux(jeu);
            }
           
        }

        public void SauvegardeDonnees()
        {
            Persistance.SauvegardeDonnees(ListJeux, Utilisateurs);
        }

    }
}
