/**
 * \file PageAdmin.xaml.cs
 * \brief Fonctionnalits administrateur
 * Code regroupant les fonctionnalits administrateur de l'application (gestion des jeux)
 */

using Microsoft.Maui.Controls;
using GameAtlas.Models;
using System.Diagnostics;

namespace GameAtlas.Views;

public partial class PageAdmin : ContentPage
{
    public Manager AdminManager => (App.Current as App).MyManager;
    public PageAdmin()
    {
        InitializeComponent();
    }

    /**
     * \brief Flche de retour en arrire
     * \return void
     */
    async void Back_Tapped(System.Object sender, Microsoft.Maui.Controls.TappedEventArgs e)
    {
        await Navigation.PopAsync();
    }

    /**
     * \brief Bouton d'ajout de jeu
     *        Affiche une succession de pop-up, pour remplir les champs un par un.
     *        Traitement et vrification des champs.
     * \return void
     */
    private async void OnButtonClicked(object sender, EventArgs e)
    {
        string nom = string.Empty;
        string sortie = string.Empty;
        string plateformes = string.Empty;
        string developpeur = string.Empty;
        string editeur = string.Empty;
        string note = string.Empty;
        string nbTelechargement = string.Empty;
        string genre = string.Empty;
        string image = string.Empty;

        int etape = 1;
        bool annuler = false;

        while (etape <= 9 && !annuler)
        {
            switch (etape)
            {
                case 1:
                    nom = await DisplayPromptAsync("Informations sur le Jeu [1/9]", "Quel est le Titre ?", accept: "Suivant", cancel: "Annuler", placeholder: "GTA VI");
                    if (string.IsNullOrEmpty(nom))
                    {
                        annuler = true;
                    }
                    break;
                case 2:
                    sortie = await DisplayPromptAsync("Informations sur le Jeu [2/9]", "Date de Sortie", accept: "Suivant", cancel: "Annuler", placeholder: "JJ/MM/AAAA");
                    if (string.IsNullOrEmpty(sortie))
                    {
                        annuler = true;
                    }
                    break;
                case 3:
                    plateformes = await DisplayPromptAsync("Informations sur le Jeu [3/9]", "Plateforme(s), un espace pour sparer", accept: "Suivant", cancel: "Annuler", placeholder: "Ex: XOne PC PS5");
                    if (string.IsNullOrEmpty(plateformes))
                    {
                        annuler = true;
                    }
                    break;
                case 4:
                    developpeur = await DisplayPromptAsync("Informations sur le Jeu [4/9]", "Dveloppeur", accept: "Suivant", cancel: "Annuler", placeholder: "Rockstar Games");
                    if (string.IsNullOrEmpty(developpeur))
                    {
                        annuler = true;
                    }
                    break;
                case 5:
                    editeur = await DisplayPromptAsync("Informations sur le Jeu [5/9]", "Editeur", accept: "Suivant", cancel: "Annuler", placeholder: "Take-Two Interactive");
                    if (string.IsNullOrEmpty(editeur))
                    {
                        annuler = true;
                    }
                    break;
                case 6:
                    note = await DisplayPromptAsync("Informations sur le Jeu [6/9]", "Note de 0  5", accept: "Suivant", cancel: "Annuler", maxLength: 1, placeholder: "5");
                    if (string.IsNullOrEmpty(note))
                    {
                        annuler = true;
                    }
                    break;
                case 7:
                    nbTelechargement = await DisplayPromptAsync("Informations sur le Jeu [7/9]", "Nombre de Tlchargements (en milliers, ex: 630k)", accept: "Suivant", cancel: "Annuler", placeholder: "630");
                    if (string.IsNullOrEmpty(nbTelechargement))
                    {
                        annuler = true;
                    }
                    break;
                case 8:
                    genre = await DisplayPromptAsync("Informations sur le Jeu [8/9]", "Genre(s), un espace pour sparer", accept: "Suivant", cancel: "Annuler", placeholder: "Action Aventure");
                    if (string.IsNullOrEmpty(genre))
                    {
                        annuler = true;
                    }
                    break;
                case 9:
                    image = await DisplayPromptAsync("Informations sur le Jeu [9/9]", "Image de couverture (prfrez URL finissant par .png)", accept: "Terminer", cancel: "Annuler", placeholder: "http://example.com/monimage.png");
                    if (string.IsNullOrEmpty(image))
                    {
                        annuler = true;
                    }
                    break;
            }

            etape++;
        }

        if (!annuler)
        {
            Jeu adminJeu = new Jeu(nom, sortie, plateformes, developpeur, editeur, Convert.ToInt32(note), Convert.ToInt32(nbTelechargement), genre, image);
            AdminManager.AddJeux(adminJeu);
            AdminManager.SauvegardeDonnees();
            AdminManager.OnPropertyChanged(nameof(AdminManager.ListJeux));

            Debug.WriteLine($"Le jeu \"{adminJeu.Nom}\" a t ajout.");
        }
        else
        {
            Debug.WriteLine("Annulation de l'ajout du jeu.");
        }
    }
}